==> lxqt-powermanagement_0.17.1.orig.tar.xz: lxqt-powermanagement-0.17.1/src/translations/lxqt-powermanagement_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Takmer vybité</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Vybíja sa</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Úplne nabité</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Nabíja sa</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Lithium ion</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Lithium polymer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium železo fosfát</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Olovená</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nikel kadmium</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nikel metal hybrid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Neznáma</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Batéria osobného digitálneho asistenta (PDA)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Batéria zdroja neprerušovaného napájania (UPS)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Primárna batéria</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Batéria myši</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Batéria klávesnice</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Batéria klávesnice a myši</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Batéria fotoaparátu/kamery</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Batéria telefónu</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Monitorovať batériu</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Neznáme batéria</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Informácie o batérii</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Správa napájania</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Teplota:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Kapacita z výroby:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Zostávajúca kapacita:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Aktuálne nabitie:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Intenzita vybíjania:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technológia:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Napätie:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Výrobca:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Žiadna batéria!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt sa nepodarili nájsť údaje o žiadnej batérii - sledovanie je preto vypnuté</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>Takmer vybité!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Uspanie do pamäti za %n sekundu</numerusform>
            <numerusform>Uspanie do pamäti za %n sekundy</numerusform>
            <numerusform>Uspanie do pamäti za %n sekúnd</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Uspanie na disk za %n sekundu</numerusform>
            <numerusform>Uspanie na disk za %n sekundy</numerusform>
            <numerusform>Uspanie na disk za %n sekúnd</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Vypnutie za %n sekundu</numerusform>
            <numerusform>Vypnutie za %n sekundy</numerusform>
            <numerusform>Vypnutie za %n sekúnd</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Správca napájania</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>LXQt správa napájania je spustená prvý krát.
Parametre je možné upraviť v Nastaveniach… </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Nastaviť…</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="60"/>
        <source>Configure</source>
        <translation>Nastaviť</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="62"/>
        <location filename="../trayicon.cpp" line="93"/>
        <source>About</source>
        <translation>O aplikácii</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="64"/>
        <source>Disable icon</source>
        <translation>Nezobrazovať ikonu</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Správa napájania&lt;/b&gt;&lt;br/&gt;  – správa napájania pre pracovné prostredie LXQt&lt;/p&gt;&lt;p&gt;  Autori:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; – a ďalší z projektov Razor a LXQt&lt;/p&gt;&lt;p&gt;  Autorské práva &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="112"/>
        <source>LXQt Power Management info</source>
        <translation>Informácie zo spravy napájania LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Zobrazovanie ikony správy napájania v systémovom panely je možné (znovu) zapnúť v &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="115"/>
        <source>Configure now</source>
        <translation>Nastaviť teraz</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement-1.1.0.tar.xz: lxqt-powermanagement-1.1.0/src/translations/lxqt-powermanagement_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Empty</source>
        <translation>Takmer vybité</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>Vybíja sa</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Úplne nabité</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>Nabíja sa</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Lithium ion</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Lithium polymer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium železo fosfát</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Olovená</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Nikel kadmium</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Nikel metal hybrid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Neznáma</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Batéria osobného digitálneho asistenta (PDA)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Batéria zdroja neprerušovaného napájania (UPS)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Primárna batéria</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Batéria myši</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Batéria klávesnice</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Batéria klávesnice a myši</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Batéria fotoaparátu/kamery</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Batéria telefónu</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Monitorovať batériu</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Neznáme batéria</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hodina</numerusform>
            <numerusform>%n hodiny</numerusform>
            <numerusform>%n hodín</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%n minute(s)</source>
        <translation>
            <numerusform>%n minúta</numerusform>
            <numerusform>%n minúty</numerusform>
            <numerusform>%n minút</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation>Zostáva %1</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation>do úplného nabitia %1</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Informácie o batérii</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Správa napájania</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Teplota:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Kapacita z výroby:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Zostávajúca kapacita:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Aktuálne nabitie:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Intenzita vybíjania:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technológia:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Napätie:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Výrobca:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Žiadna batéria!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt sa nepodarili nájsť údaje o žiadnej batérii - sledovanie je preto vypnuté</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Takmer vybité!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Uspanie do pamäti za %n sekundu</numerusform>
            <numerusform>Uspanie do pamäti za %n sekundy</numerusform>
            <numerusform>Uspanie do pamäti za %n sekúnd</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Uspanie na disk za %n sekundu</numerusform>
            <numerusform>Uspanie na disk za %n sekundy</numerusform>
            <numerusform>Uspanie na disk za %n sekúnd</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Vypnutie za %n sekundu</numerusform>
            <numerusform>Vypnutie za %n sekundy</numerusform>
            <numerusform>Vypnutie za %n sekúnd</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Tlačítko vypnutia</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Tlačítko vypnutia</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Tlačítko uspania</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Správca napájania</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>LXQt správa napájania je spustená prvý krát.
Parametre je možné upraviť v Nastaveniach… </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Nastaviť…</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="67"/>
        <source>Configure</source>
        <translation>Nastaviť</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="75"/>
        <source>30 minutes</source>
        <translation>30 minút</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="79"/>
        <source>1 hour</source>
        <translation>1 hodina</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="83"/>
        <source>2 hours</source>
        <translation>2 hodiny</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="87"/>
        <source>3 hours</source>
        <translation>3 hodiny</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="91"/>
        <source>4 hours</source>
        <translation>4 hodiny</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="96"/>
        <source>Pause idleness checks</source>
        <translation>Pozastaviť zisťovanie neaktivity</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="101"/>
        <location filename="../trayicon.cpp" line="191"/>
        <source>About</source>
        <translation>O aplikácii</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="103"/>
        <source>Disable icon</source>
        <translation>Nezobrazovať ikonu</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="192"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Správa napájania&lt;/b&gt;&lt;br/&gt;  – správa napájania pre pracovné prostredie LXQt&lt;/p&gt;&lt;p&gt;  Autori:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; – a ďalší z projektov Razor a LXQt&lt;/p&gt;&lt;p&gt;  Autorské práva &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="210"/>
        <source>LXQt Power Management info</source>
        <translation>Informácie zo spravy napájania LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="211"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Zobrazovanie ikony správy napájania v systémovom panely je možné (znovu) zapnúť v &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="213"/>
        <source>Configure now</source>
        <translation>Nastaviť teraz</translation>
    </message>
</context>
</TS>
